
API
===


Base
----

.. autoclass:: flask_authorize.plugin.Authorize
   :members:



Databse Mixins
--------------

.. autoclass:: flask_authorize.mixins.PermissionsMixin
   :members:

.. autoclass:: flask_authorize.mixins.PermissionsMixin
   :members:
